@@ -4,7 +4,7 @@
 
     Python SDK
 
-    OpenAPI spec version: 3.2.3
+    OpenAPI spec version: 3.4.0
     
 """
 
@@ -58,13 +58,13 @@ class ApiClient:
         self.default_headers = {}
 
         for name, value in configuration.default_headers.items():
-            self.default_headers[name] = value;
+            self.default_headers[name] = value
 
         if header_name is not None:
             self.default_headers[header_name] = header_value
         self.cookie = cookie
         # Set default User-Agent.
-        self.user_agent = 'whitelabelmachinename/3.2.3/python'
+        self.user_agent = 'whitelabelmachinename/3.4.0/python'
 
     def __del__(self):
         if self._pool is not None:
@@ -103,7 +103,7 @@ class ApiClient:
 
         # predefined default headers
         default_headers = {
-            'x-meta-sdk-version': '3.2.3',
+            'x-meta-sdk-version': '3.4.0',
             'x-meta-sdk-language': 'python',
             'x-meta-sdk-provider': 'WhiteLabelName',
             'x-meta-sdk-language-version': platform.python_version()
