@@ -176,7 +176,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def created_on(self):
         """Gets the created_on of this ChargeAttempt.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :return: The created_on of this ChargeAttempt.
         :rtype: datetime
@@ -187,7 +187,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def created_on(self, created_on):
         """Sets the created_on of this ChargeAttempt.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :param created_on: The created_on of this ChargeAttempt.
         :type: datetime
@@ -360,7 +360,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def language(self):
         """Gets the language of this ChargeAttempt.
 
-            
+            The language that is linked to the object.
 
         :return: The language of this ChargeAttempt.
         :rtype: str
@@ -371,7 +371,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def language(self, language):
         """Sets the language of this ChargeAttempt.
 
-            
+            The language that is linked to the object.
 
         :param language: The language of this ChargeAttempt.
         :type: str
@@ -406,7 +406,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def planned_purge_date(self):
         """Gets the planned_purge_date of this ChargeAttempt.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this ChargeAttempt.
         :rtype: datetime
@@ -417,7 +417,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this ChargeAttempt.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this ChargeAttempt.
         :type: datetime
@@ -498,7 +498,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def state(self):
         """Gets the state of this ChargeAttempt.
 
-            
+            The object's current state.
 
         :return: The state of this ChargeAttempt.
         :rtype: ChargeAttemptState
@@ -509,7 +509,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def state(self, state):
         """Sets the state of this ChargeAttempt.
 
-            
+            The object's current state.
 
         :param state: The state of this ChargeAttempt.
         :type: ChargeAttemptState
@@ -661,7 +661,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def version(self):
         """Gets the version of this ChargeAttempt.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this ChargeAttempt.
         :rtype: int
@@ -672,7 +672,7 @@ class ChargeAttempt(TransactionAwareEntity):
     def version(self, version):
         """Sets the version of this ChargeAttempt.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this ChargeAttempt.
         :type: int
