@@ -113,7 +113,7 @@ class InvoiceReimbursement:
     def created_on(self):
         """Gets the created_on of this InvoiceReimbursement.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :return: The created_on of this InvoiceReimbursement.
         :rtype: datetime
@@ -124,7 +124,7 @@ class InvoiceReimbursement:
     def created_on(self, created_on):
         """Sets the created_on of this InvoiceReimbursement.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :param created_on: The created_on of this InvoiceReimbursement.
         :type: datetime
@@ -205,7 +205,7 @@ class InvoiceReimbursement:
     def id(self):
         """Gets the id of this InvoiceReimbursement.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this InvoiceReimbursement.
         :rtype: int
@@ -216,7 +216,7 @@ class InvoiceReimbursement:
     def id(self, id):
         """Sets the id of this InvoiceReimbursement.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this InvoiceReimbursement.
         :type: int
@@ -228,7 +228,7 @@ class InvoiceReimbursement:
     def linked_space_id(self):
         """Gets the linked_space_id of this InvoiceReimbursement.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this InvoiceReimbursement.
         :rtype: int
@@ -239,7 +239,7 @@ class InvoiceReimbursement:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this InvoiceReimbursement.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this InvoiceReimbursement.
         :type: int
@@ -527,7 +527,7 @@ class InvoiceReimbursement:
     def state(self):
         """Gets the state of this InvoiceReimbursement.
 
-            
+            The object's current state.
 
         :return: The state of this InvoiceReimbursement.
         :rtype: InvoiceReimbursementState
@@ -538,7 +538,7 @@ class InvoiceReimbursement:
     def state(self, state):
         """Sets the state of this InvoiceReimbursement.
 
-            
+            The object's current state.
 
         :param state: The state of this InvoiceReimbursement.
         :type: InvoiceReimbursementState
@@ -550,7 +550,7 @@ class InvoiceReimbursement:
     def version(self):
         """Gets the version of this InvoiceReimbursement.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this InvoiceReimbursement.
         :rtype: int
@@ -561,7 +561,7 @@ class InvoiceReimbursement:
     def version(self, version):
         """Sets the version of this InvoiceReimbursement.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this InvoiceReimbursement.
         :type: int
